==> entity_bulk_clone-8.x-1.0.tar.gz: entity_bulk_clone/src/Plugin/Action/BulkCloneNode.php <==
<?php

namespace Drupal\entity_bulk_clone\Plugin\Action;

use Drupal\Core\Action\ActionBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Entity Bulk clone of nodes.
 *
 * @Action(
 *   id = "bulk_clone_node_action",
 *   label = @Translation("Bulk Clone"),
 *   type = "node",
 *   confirm = TRUE
 * )
 */
class BulkCloneNode extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function executeMultiple(array $objects) {
    $results = [];
    foreach ($objects as $entity) {
      $results[] = $this->execute($entity);
    }

    if (isset($results) && !empty($results)) {
      $batch = [
        'title' => t('Content Bulk Cloning...'),
        'operations' => $results,
        'finished' => '\Drupal\entity_bulk_clone\Plugin\BulkCloneNode::batchFinished',
      ];
      batch_set($batch);
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function batchFinished($success, $results, $operations) {
    if (!empty($success)) {
      $message = count($results) . ' batches processed.';
      \Drupal::messenger()->addStatus($message);
    }
    else {
      \Drupal::messenger()->addError("bulk clone failed.");
    }
  }

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    $replicator = \Drupal::service('replicate.replicator');
    $duplicate_entity = $replicator->replicateByEntityId($entity->getEntityTypeId(), $entity->id());
    $title = $duplicate_entity->getTitle();
    $duplicate_entity->setTitle($title . ' - Bulk Cloned');
    $duplicate_entity->setChangedTime(REQUEST_TIME);
    $duplicate_entity->save();
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    $result = $object
      ->access('update', $account, TRUE)
      ->andIf($object->status->access('edit', $account, TRUE));

    return $return_as_object ? $result : $result->isAllowed();
  }

}

==> entity_bulk_clone-8.x-1.1.tar.gz: entity_bulk_clone/src/Plugin/Action/BulkCloneNode.php <==
<?php

namespace Drupal\entity_bulk_clone\Plugin\Action;

use Drupal\Core\Action\ActionBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Entity Bulk clone of nodes.
 *
 * @Action(
 *   id = "bulk_clone_node_action",
 *   label = @Translation("Bulk Clone"),
 *   type = "node",
 *   confirm = TRUE
 * )
 */
class BulkCloneNode extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function executeMultiple(array $objects) {
    $results = [];
    foreach ($objects as $entity) {
      $results[] = $this->execute($entity);
    }

    if (isset($results) && !empty($results)) {
      $batch = [
        'title' => t('Content Bulk Cloning...'),
        'operations' => $results,
        'finished' => '\Drupal\entity_bulk_clone\Plugin\BulkCloneNode::batchFinished',
      ];
      batch_set($batch);
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function batchFinished($success, $results, $operations) {
    // The 'success' parameter means no fatal PHP errors were detected.
    if ($success) {
      $message = \Drupal::translation()
        ->formatPlural(count($results), 'Bulk Clone was applied to ', '@count items.');
      \Drupal::messenger()->addStatus($message);
    }
    else {
      $message = t('Finished with an error.');
      \Drupal::messenger()->addError($message);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    $replicator = \Drupal::service('replicate.replicator');
    $duplicate_entity = $replicator->replicateByEntityId($entity->getEntityTypeId(), $entity->id());
    $title = $duplicate_entity->getTitle();
    $duplicate_entity->setTitle($title . ' - Bulk Cloned');
    $duplicate_entity->setChangedTime(REQUEST_TIME);
    $duplicate_entity->save();
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    $result = $object
      ->access('update', $account, TRUE)
      ->andIf($object->status->access('edit', $account, TRUE));

    return $return_as_object ? $result : $result->isAllowed();
  }

}
